%define anolis_release 3
%bcond_without long_tests
%bcond_with optional_test
%global modname IO-Compress

%{?perl_default_filter}

Name:           perl-%{modname}
Version:        2.201
Release:        %{anolis_release}%{?dist}
Summary:        Read and write compressed data
License:        GPL-1.0-or-later OR Artistic-1.0-Perl
URL:            https://metacpan.org/release/%{modname}
Source0:        https://cpan.metacpan.org/modules/by-module/IO/%{modname}-%{version}.tar.gz

BuildRequires:  make coreutils findutils perl-generators perl-interpreter
BuildRequires:  perl(Config) perl(lib) perl(bytes) perl(Carp) perl(constant)
BuildRequires:  perl(File::Copy) perl(File::Spec::Functions) perl(File::Glob)
BuildRequires:  perl(Compress::Raw::Bzip2) >= %{version}
BuildRequires:  perl(Compress::Raw::Zlib) >= %{version}
BuildRequires:  perl(ExtUtils::MakeMaker) >= 6.76
BuildRequires:  perl(Fcntl) perl(Encode) perl(Exporter)
BuildRequires:  perl(File::Spec) perl(IO::File) perl(File::Path) perl(List::Util)
BuildRequires:  perl(Symbol) perl(strict) perl(Scalar::Util) perl(threads::shared)
BuildRequires:  perl(Time::Local) perl(utf8) perl(warnings) perl(IO::Handle)

%if !%{defined perl_bootstrap}
BuildRequires:  perl(Test::More)
%endif
%if %{with optional_test}
BuildRequires:  perl(bytes) perl(Data::Dumper) perl(File::Temp) perl(overload)
%if !%{defined perl_bootstrap}
BuildRequires:  perl(Test::NoWarnings)
%endif
%endif

Requires:       perl(File::Glob)

Provides:       perl-Compress-Zlib = %{EVR}
Provides:       perl-%{modname}-Base = %{EVR}
Provides:       perl-%{modname}-Bzip2 = %{EVR}
Provides:       perl-%{modname}-Zlib = %{EVR}
Obsoletes:      perl-Compress-Zlib < %{EVR}
Obsoletes:      perl-%{modname}-Base < %{EVR}
Obsoletes:      perl-%{modname}-Bzip2 < %{EVR}
Obsoletes:      perl-%{modname}-Zlib < %{EVR}
Obsoletes:      perl-%{modname}-tests < %{EVR}

# Filter modules bundled for tests
%global __requires_exclude %{?__requires_exclude:%__requires_exclude|}perl\\(CompTestUtils\\)
%global __requires_exclude %{__requires_exclude}|^perl\\(.*\.pl)\s*$
%if %{defined perl_bootstrap}
%global __requires_exclude %{__requires_exclude}|^perl\\(Test::Builder)\s*$
%global __requires_exclude %{__requires_exclude}|^perl\\(Test::More)\s*$
%global __requires_exclude %{__requires_exclude}|^perl\\(Test::Simple)\s*$
%endif
%global __provides_exclude_from %{?__provides_exclude_from:%__provides_exclude_from|}^%{_libexecdir}

BuildArch:      noarch

%description
This distribution provides a Perl interface to allow reading and writing of
compressed data created with the zlib and bzip2.

IO-Compress supports reading and writing of the following compressed data formats
  * bzip2
  * RFC 1950
  * RFC 1951
  * RFC 1952 (i.e. gzip)
  * zip

There are a number of companion modules for IO-Compress that extend
the suite of compression formats available.

 * IO-Compress-Zstd
   Adds support for zstd (Zstandard).
 * IO-Compress-Lzma
   Adds support for lzma, xz and lzip.
 * IO-Compress-Lzf
   Adds support for lzf.
 * IO-Compress-Lzop
   Adds support for lzop.

Note that the following modules used to be distributed separately, but are now
included with the IO-Compress distribution.

    Compress-Zlib
    IO-Compress-Zlib
    IO-Compress-Bzip2
    IO-Compress-Base

%package doc
Summary:        Documentation files for %{name}
Requires:       %{name} = %{EVR}
BuildArch:      noarch

%description    doc
The %{name}-doc package contains documentation files for %{name}.

%prep
%autosetup -n %{modname}-%{version}

chmod -x lib/IO/Uncompress/{Adapter/Identity,RawInflate}.pm
find examples -type f -exec chmod -x {} \;

%if ! %{defined perl_bootstrap}
rm -rf t/Test
perl -i -ne 'print $_ unless m{^t/Test/}' MANIFEST
%endif

perl -MConfig -pi -e 's|^#!/usr/local/bin/perl\b|$Config{startperl}|' \
	examples/io/anycat \
	examples/io/bzip2/* \
	examples/io/gzip/* \
	examples/compress-zlib/*

for F in `find t -name *.t` `find t -name *.pl`; do
    perl -i -MConfig -ple 'print $Config{startperl} if $. == 1 && !s{\A#!.*perl\b}{$Config{startperl}}' "$F"
    chmod +x "$F"
done

%build
perl Makefile.PL NO_PACKLIST=1 NO_PERLLOCAL=1
%make_build

%install
%make_install INSTALLDIRS=perl
%{_fixperms} -c %{buildroot}

%check
TEST_SKIP_VERSION_CHECK=1  \
	make test COMPRESS_ZLIB_RUN_%{?with_long_tests:ALL}%{!?with_long_tests:MOST}=1

%files
%{_bindir}/streamzip
%{_bindir}/zipdetails

%dir %{perl_privlib}/IO/
%dir %{perl_privlib}/IO/Compress/
%{perl_privlib}/Compress/
%{perl_privlib}/File/
%{perl_privlib}/IO/Compress/Adapter/
%{perl_privlib}/IO/Compress/Base/
%{perl_privlib}/IO/Compress/Base.pm
%{perl_privlib}/IO/Compress/Bzip2.pm
%{perl_privlib}/IO/Compress/Deflate.pm
%{perl_privlib}/IO/Compress/Gzip/
%{perl_privlib}/IO/Compress/Gzip.pm
%{perl_privlib}/IO/Compress/RawDeflate.pm
%{perl_privlib}/IO/Compress/Zip/
%{perl_privlib}/IO/Compress/Zip.pm
%{perl_privlib}/IO/Compress/Zlib/
%{perl_privlib}/IO/Uncompress/

%{_mandir}/man1/streamzip.1*
%{_mandir}/man1/zipdetails.1*
%{_mandir}/man3/Compress::Zlib.3*
%{_mandir}/man3/File::GlobMapper.3*
%{_mandir}/man3/IO::Compress::*.3*
%{_mandir}/man3/IO::Uncompress::*.3*
%doc %{perl_privlib}/IO/Compress/FAQ.pod

%files doc
%doc README Changes examples/*

%changelog
* Thu Apr 13 2023 Yuanhong Peng <yummypeng@linux.alibaba.com> - 2.201-3
- Refactor the specfile and remove tests sub-package

* Tue Feb 07 2023 mgb01105731 <mgb01105731@alibaba-inc.com> - 2.201-2
- add doc

* Mon Jan 30 2023 Chunmei Xu <xuchunmei@linux.alibaba.com> - 2.201-1
- update to 2.201

-* Thu Apr 21 2022 zhang xianting <zhangxianting@uniontech.com> - 2.103-1
-- Initial build for Anolis V23
